pub struct SitData {
pub sit_name: String,
pub orientation: Vec3,
pub legacy_orientation_ll: Vec3,
pub position: Vec3,
pub legacy_position_ll: Vec3,
}Expand description
Information about how the object can be sat on.
Fields
sit_name: StringCustom name that is displayed when the user right-clicks to sit. Could be things like “sit”, “pose”, “lounge” etc
orientation: Vec3How to rotate the avatar that sits down
legacy_orientation_ll: Vec3Undocumented. Maybe legacy rotation vector
position: Vec3XYZ position the avatar should be placed when sitting.
legacy_position_ll: Vec3Undocumented. Maybe legacy position vector.