CameraPosition

Struct CameraPosition 

pub struct CameraPosition {
    pub position: Vec3,
}
this is the struct for sending mesh updates from the core to the UI. the path is the path to the generated gltf file, and the position is where to place it in the world.

Fields

position: Vec3

the position of the camera in the region